@@ -24,6 +24,7 @@ from dateutil.relativedelta import relativedelta
 from random import choice
 from random import randint
 from random import uniform
+import calendar
 
 from nise.generators.generator import AbstractGenerator
 
@@ -84,19 +85,59 @@ GCP_REPORT_COLUMNS_JSONL = (
 GCP_INSTANCE_TYPES = ("e2-medium", "n1-standard-4", "m2-megamem-416", "a2-highgpu-1g")
 
 
-def apply_previous_invoice_month(row):
+def apply_different_invoice_month(row, invoice_shift):
+    """
+    Adjusts the invoice month of a data row by a given month shift.
+
+    This function handles two possible data structures for the invoice month:
+    1. A flat key: `{"invoice.month": "202509", ...}`
+    2. A nested dictionary: `{"invoice": {"month": "202509"}, ...}`
+
+    It creates a copy of the row, finds the month, applies the shift, and
+    updates the row while preserving the original structure.
+
+    Args:
+        row (dict): The data row containing invoice information.
+        invoice_shift (int): The number of months to shift. Can be positive
+                             (for future months) or negative (for past months).
+
+    Returns:
+        dict: A new dictionary with the adjusted invoice month. If the invoice
+              month cannot be found or is malformed, it returns an unmodified
+              copy of the original row.
+    """
     new_row = row.copy()
     if invoice_month := new_row.get("invoice.month"):
-        date_object = datetime.datetime.strptime(invoice_month, "%Y%m")
-        previous_month_object = date_object - relativedelta(months=1)
-        new_row["invoice.month"] = previous_month_object.strftime("%Y%m")
-        return new_row
-    if invoice_dict := new_row.get("invoice"):
-        date_object = datetime.datetime.strptime(invoice_dict["month"], "%Y%m")
-        previous_month_object = date_object - relativedelta(months=1)
-        new_row["invoice"] = {"month": previous_month_object.strftime("%Y%m")}
+        invoice_month_date_object = datetime.datetime.strptime(invoice_month, "%Y%m")
+    elif invoice_dict := new_row.get("invoice"):
+        invoice_month_date_object = datetime.datetime.strptime(invoice_dict["month"], "%Y%m")
+    else:
         return new_row
 
+    adjusted_date = invoice_month_date_object + relativedelta(months=invoice_shift)
+    adjusted_month = adjusted_date.strftime("%Y%m")
+    if "invoice.month" in new_row:
+        new_row["invoice.month"] = adjusted_month
+    elif "invoice" in new_row:
+        new_row["invoice"] = {"month": adjusted_month}
+    return new_row
+
+
+def get_months_in_range(start_date, end_date):
+    """
+    Generates a list of all months between a start and end date, inclusive.
+    """
+
+    months = []
+    current_date = start_date.date().replace(day=1)
+    end_month_start = end_date.date().replace(day=1)
+
+    while current_date <= end_month_start:
+        months.append(current_date)
+        current_date += relativedelta(months=1)
+
+    return months
+
 
 class GCPGenerator(AbstractGenerator):
     """Abstract class for GCP generators."""
@@ -126,11 +167,10 @@ class GCPGenerator(AbstractGenerator):
         self._resource_name = self.attributes.get("resource.name")
         self._resource_global_name = self.attributes.get("resource.global_name")
         self._service = self.attributes.get("service.description")
-        self._cross_over_data = self.attributes.get("cross_over_data")
+        self._cross_over_metadata = self.attributes.get("cross_over", {})
         self._instance_type = self.attributes.get("instance_type", choice(GCP_INSTANCE_TYPES))
         self._currency = self.attributes.get("currency", currency)
         self._sku = None
-        self._cross_over_rows = []
 
     @staticmethod
     def _create_days_list(start_date, end_date):
@@ -303,15 +343,111 @@ class GCPGenerator(AbstractGenerator):
     def _update_data(self, row, start, end, **kwargs):
         """Update a data row."""
 
+    def _is_invoice_shift_applicable_to_month(self, month_to_check_start):
+        """
+        Determines if the cross-over logic applies to a specific month.
+
+        Args:
+            month_to_check_start (datetime.date): The first day of the month to check.
+
+        Returns:
+            bool: True if the invoice shift logic should be applied, False otherwise.
+        """
+        now = datetime.datetime.now(datetime.UTC)
+        month_setting = self._cross_over_metadata.get("month", "all")
+
+        if month_setting == "current":
+            current_month_start = now.date().replace(day=1)
+            is_applicable_this_month = month_to_check_start == current_month_start
+        elif month_setting == "previous":
+            previous_month_start = (now - relativedelta(months=1)).date().replace(day=1)
+            is_applicable_this_month = month_to_check_start == previous_month_start
+        else:
+            is_applicable_this_month = True
+        return is_applicable_this_month
+
+    def _get_day_to_shift_map(self, cross_over_day_specifiers, start_dt, end_dt):
+        """
+        Calculates the map of days to invoice shifts based on cross-over settings.
+        """
+        day_to_shift_map = {}
+        if not cross_over_day_specifiers:
+            return day_to_shift_map
+
+        # Get list of all months generated in current batch
+        months_in_data = get_months_in_range(start_dt, end_dt)
+
+        # Check which of those months the invoice shift is applicable to
+        months_to_shift = [month for month in months_in_data if self._is_invoice_shift_applicable_to_month(month)]
+
+        # Build a mapping of {month: {day_of_month: invoice_month_shift}}
+        for month in months_to_shift:
+            month_key = month.month
+            day_to_shift_map[month_key] = {}
+            _, num_days_in_month = calendar.monthrange(month.year, month_key)
+
+            # A shift of -1 moves the cost to the previous month's invoice.
+            # A shift of +1 moves the cost to the next month's invoice.
+            for day in cross_over_day_specifiers:
+                if day > 0:  # Day is from the start of the month
+                    day_to_shift_map[month_key][day] = -1
+                else:  # Day is from the end of the month
+                    day_from_start = num_days_in_month + day + 1
+                    day_to_shift_map[month_key][day_from_start] = 1
+
+        return day_to_shift_map
+
     def _generate_hourly_data(self, **kwargs):
-        """Not needed for GCP."""
+        """
+        Generates hourly cost data, applying invoice date shifts for specific days.
+
+        This generator function iterates through hourly usage data. For specific days
+        defined in the 'cross_over' configuration, it can shift the cost to the
+        invoice of the previous or next month. This is useful for simulating billing
+        scenarios where costs incurred at the very beginning or end of a month are
+        billed in an adjacent month.
+
+        The behavior is controlled by `self._cross_over_metadata` (from YAML):
+        - `month` (str): 'current', 'previous', or 'all'. Determines to which month(s)
+                         the cross-over logic should apply. Defaults to 'all'.
+        - `days` (list[int]): A list of day specifiers.
+                            - Positive numbers (e.g., 2) shift costs to the *previous* month.
+                            - Negative numbers (e.g., -1 for the last day) count from the end of the month and shift
+                            costs to the *next* month.
+        - `overwrite` (bool): If True, the original cost entry is replaced by the
+                              shifted one. If False, the original is kept, and a new
+                              shifted entry is also created.
+
+        Note:
+            This function assumes that all data in `self.hours` belongs to the
+            same calendar month. Behavior is undefined if hours span a month boundary.
+        """
+
+        if not self.hours:
+            return
+
+        # --- 1. Initialization and Setup ---
+        overwrite = self._cross_over_metadata.get("overwrite", False)
+        cross_over_day_specifiers = self._cross_over_metadata.get("days", [])
+
+        # --- 2. Calculate Invoice Shifts  ---
+        start_dt = self.hours[0].get("start")
+        end_dt = self.hours[-1].get("start")
+        day_to_shift_map = self._get_day_to_shift_map(cross_over_day_specifiers, start_dt, end_dt)
+
+        # --- 3. Process Each Hour, Applying Invoice Shifts Where Necessary ---
         for hour in self.hours:
-            start = hour.get("start")
-            end = hour.get("end")
+            start, end = hour.get("start"), hour.get("end")
             row = self._init_data_row(start, end)
             row = self._update_data(row)
+
+            # Check if the current day has a defined shift
+            if shift_direction := day_to_shift_map.get(start.month, {}).get(start.day):
+                # This is a cross-over day, so yield the modified row.
+                yield apply_different_invoice_month(row, shift_direction)
+                if overwrite:
+                    # If overwriting, skip yielding the original row.
+                    continue
+
+            # Yield the original row (always, unless it was overwritten).
             yield row
-            if self._cross_over_data and start.day == 1:
-                cross_over_row = apply_previous_invoice_month(row)
-                if cross_over_row:
-                    yield cross_over_row
