@@ -24,6 +24,7 @@ from random import choices
 from random import randint
 from random import uniform
 from string import ascii_lowercase
+from uuid import uuid4
 
 from dateutil import parser
 from faker import Faker
@@ -35,6 +36,7 @@ FAKER = Faker()
 
 GIGABYTE = 1024 * 1024 * 1024
 HOUR = 60 * 60
+AWS_RESID_LENGTH = 17
 
 OCP_POD_USAGE = "ocp_pod_usage"
 OCP_STORAGE_USAGE = "ocp_storage_usage"
@@ -475,7 +477,7 @@ class OCPGenerator(AbstractGenerator):
             for item in self._nodes:
                 memory_gig = item.get("memory_gig", randint(2, 8))
                 memory_bytes = memory_gig * GIGABYTE
-                resource_id = str(item.get("resource_id", self.fake.word()))
+                resource_id = str(item.get("resource_id", uuid4().hex[:AWS_RESID_LENGTH]))
                 # Handle empty namespaces
                 raw_namespaces = item.get("namespaces", {})
                 if raw_namespaces is None:
@@ -503,7 +505,7 @@ class OCPGenerator(AbstractGenerator):
                     "name": "node_" + self.fake.word(),
                     "cpu_cores": randint(2, 16),
                     "memory_bytes": memory_bytes,
-                    "resource_id": "i-" + self.fake.word(),
+                    "resource_id": "i-" + uuid4().hex[:AWS_RESID_LENGTH],
                     "node_labels": self._gen_openshift_labels(seeding=seeded_labels),
                 }
                 nodes.append(node)
@@ -597,7 +599,7 @@ class OCPGenerator(AbstractGenerator):
             "pod_seconds": specified_pod.get("pod_seconds"),
         }
 
-        owner_name, owner_kind, workload, workload_type = get_owner_workload(pod, specified_pod.get("workload"))
+        owner_name, owner_kind, workload, workload_type = get_owner_workload(pod_name, specified_pod.get("workload"))
 
         cpu_usage_avg, cpu_usage_min, cpu_usage_max = generate_randomized_ros_usage(
             cpu_usage, cpu_limit, generate_constant_value=self.constant_values_ros_ocp
@@ -682,8 +684,8 @@ class OCPGenerator(AbstractGenerator):
                 for _ in range(num_pods):
                     pod_suffix = "".join(choices(ascii_lowercase, k=5))
                     pod_type = choice(("build", "deploy", pod_suffix))
-                    pod = f"{self.fake.word()}_{pod_type}"
-                    namespace2pod[namespace].append(pod)
+                    pod_name = f"{self.fake.word()}_{pod_type}"
+                    namespace2pod[namespace].append(pod_name)
                     cpu_cores = node.get("cpu_cores")
                     cpu_limit = round(uniform(0.02, cpu_cores), 5)
                     cpu_request = round(uniform(0.02, cpu_limit), 5)
@@ -692,11 +694,11 @@ class OCPGenerator(AbstractGenerator):
                     mem_limit_gig = round(uniform(25.0, memory_gig), 2)
                     mem_request_gig = round(uniform(25.0, mem_limit_gig), 2)
 
-                    pods[pod] = {
+                    pods[pod_name] = {
                         "namespace": namespace,
                         "node": node.get("name"),
                         "resource_id": node.get("resource_id"),
-                        "pod": pod,
+                        "pod": pod_name,
                         "node_capacity_cpu_cores": cpu_cores,
                         "node_capacity_cpu_core_seconds": cpu_cores * HOUR,
                         "node_capacity_memory_bytes": memory_bytes,
@@ -707,7 +709,7 @@ class OCPGenerator(AbstractGenerator):
                         "mem_limit_gig": mem_limit_gig,
                         "pod_labels": self._gen_openshift_labels(),
                     }
-                    owner_name, owner_kind, workload, workload_type = get_owner_workload(pod)
+                    owner_name, owner_kind, workload, workload_type = get_owner_workload(pod_name)
                     cpu_usage_avg, cpu_usage_min, cpu_usage_max = generate_randomized_ros_usage(
                         {}, cpu_limit, generate_constant_value=self.constant_values_ros_ocp
                     )
@@ -717,12 +719,12 @@ class OCPGenerator(AbstractGenerator):
                     memory_rss_ratio = 1 / round(uniform(1.01, 1.9), 2)
                     cpu_throttle = choices([0, round(cpu_usage_avg / randint(10, 20), 5)], weights=(3, 1))[0]
 
-                    ros_ocp_data_pods[pod] = {
+                    ros_ocp_data_pods[pod_name] = {
                         "namespace": namespace,
                         "node": node.get("name"),
                         "resource_id": node.get("resource_id"),
-                        "pod": pod,
-                        "container_name": pod,
+                        "pod": pod_name,
+                        "container_name": pod_name,
                         "owner_name": owner_name,
                         "owner_kind": owner_kind,
                         "workload": workload,
@@ -757,7 +759,7 @@ class OCPGenerator(AbstractGenerator):
 
     def _gen_specific_volume(self, node, namespace, specified_volume):
         storage_class_default, csi_default = get_storage_class_and_driver()
-        volume = specified_volume.get("volume_name", self.fake.word())
+        volume = specified_volume.get("volume_name", f"pv-{self.fake.word()}")
         volume_request_gig = specified_volume.get("volume_request_gig") or 100
         volume_request = volume_request_gig * GIGABYTE
         specified_vol_claims = specified_volume.get("volume_claims", [])
@@ -792,7 +794,7 @@ class OCPGenerator(AbstractGenerator):
             "volume": volume,
             "storage_class": specified_volume.get("storage_class", storage_class_default),
             "csi_driver": specified_volume.get("csi_driver", csi_default),
-            "csi_volume_handle": specified_volume.get("csi_volume_handle", f"vol-{self.fake.word()}"),
+            "csi_volume_handle": specified_volume.get("csi_volume_handle", f"vol-{uuid4().hex[:AWS_RESID_LENGTH]}"),
             "volume_request": volume_request,
             "labels": specified_volume.get("labels", None),
             "volume_claims": volume_claims,
@@ -812,7 +814,7 @@ class OCPGenerator(AbstractGenerator):
                 num_vol_claims = randint(1, 2)
                 for _ in range(num_volumes):
                     vol_suffix = "".join(choices(ascii_lowercase, k=10))
-                    volume = "pvc" + "-" + vol_suffix
+                    volume = "pv" + "-" + vol_suffix
                     vol_request_gig = round(uniform(25.0, 80.0), 2)
                     vol_request = vol_request_gig * GIGABYTE
                     volume_claims = {}
@@ -841,7 +843,7 @@ class OCPGenerator(AbstractGenerator):
                                 "volume": volume,
                                 "storage_class": storage_class_default,
                                 "csi_driver": csi_default,
-                                "csi_volume_handle": f"vol-{self.fake.word()}",
+                                "csi_volume_handle": f"vol-{uuid4().hex[:AWS_RESID_LENGTH]}",
                                 "volume_request": vol_request,
                                 "labels": self._gen_openshift_labels(),
                                 "volume_claims": volume_claims,
@@ -859,7 +861,7 @@ class OCPGenerator(AbstractGenerator):
                     return pvc, specific_pvc
         return "", {}
 
-    def get_vm_disk(self, *, specified_vc=None, pod_name=""):
+    def get_vm_disk(self, *, specified_vc=None, pod_name="", static_report=False):
         specified_vc = specified_vc or {}
         vm_disk = {
             "vm_device": specified_vc.get("vol_device") or "rootdisk",
@@ -873,6 +875,8 @@ class OCPGenerator(AbstractGenerator):
                     "vc_capacity": pvc["capacity"],
                 }
                 return vm_disk
+            if static_report:
+                return {}
         vm_disk |= {
             "vm_persistentvolumeclaim_name": specified_vc.get("volume_claim_name", FAKER.word()),
             "vc_capacity": specified_vc.get("capacity_gig", randint(30, 50)) * GIGABYTE,
@@ -939,7 +943,7 @@ class OCPGenerator(AbstractGenerator):
                             "vm_seconds": specified_vm.get("vm_seconds"),
                         }
                         | get_vm_instance(vm=specified_vm)
-                        | self.get_vm_disk(specified_vc=specified_vm)
+                        | self.get_vm_disk(specified_vc=specified_vm, static_report=True)
                     )
 
             else:
@@ -991,12 +995,13 @@ class OCPGenerator(AbstractGenerator):
                     self.pods[pod_name] = pod
                     self.ros_data[pod_name] = ros_pod
                     self.namespace2pods[namespace].append(pod_name)
-                if vm_copy["vm_persistentvolumeclaim_name"] not in self.pod_pvc_map.values():
+                vcm = vm_copy.get("vm_persistentvolumeclaim_name")
+                if vcm and vcm not in self.pod_pvc_map.values():
                     specified_volume = {
                         "volume_claims": [
                             {
                                 "pod_name": vm,
-                                "volume_claim_name": vm_copy["vm_persistentvolumeclaim_name"],
+                                "volume_claim_name": vcm,
                                 "capacity_gig": vm_copy["vc_capacity"] / GIGABYTE,
                             }
                         ]
@@ -1112,7 +1117,8 @@ class OCPGenerator(AbstractGenerator):
 
         vm["vm_uptime_total_seconds"] = vm_seconds
 
-        vm["vm_disk_allocated_size_byte_seconds"] = kwargs.get("vc_capacity") * HOUR
+        if vc_capacity := kwargs.get("vc_capacity"):
+            vm["vm_disk_allocated_size_byte_seconds"] = vc_capacity * HOUR
 
         row.update(vm)
         return row
